@@ -9,13 +9,13 @@ from fakts.discovery import StaticDiscovery
 from herre import Herre
 import logging
 from koil.composition import PedanticKoil
-
-
+import os
+from .utils import create_arkitekt_folder
 
 
 def easy(
-    identifier: str, version: str = "latest", url: str = "http://localhost:8000/f/", headless: bool = False, allow_sync_in_async: bool = True, log_level: str = "ERROR"
-) -> Arkitekt:
+    identifier: str, version: str = "latest", url: str = "http://localhost:8000/f/", headless: bool = False, allow_sync_in_async: bool = True, log_level: str = "ERROR",
+token: str = None) -> Arkitekt:
     """Easy app creation
 
     A simple way to create an Arkitekt app with a device code grant
@@ -33,6 +33,11 @@ def easy(
         Arkitekt: _description_
     """
 
+    url = os.getenv("FAKTS_URL", url)
+    token = os.getenv("FAKTS_TOKEN", token)
+
+    create_arkitekt_folder(with_cache=True)
+
     try:
         from rich.logging import RichHandler
 
@@ -46,7 +51,7 @@ def easy(
         koil=PedanticKoil(sync_in_async=allow_sync_in_async),
         fakts=Fakts(
             grant=CacheGrant(
-                cache_file=f"{identifier}-{version}_cache.json",
+                cache_file=f".arkitekt/cache/{identifier}-{version}_cache.json",
                 hash=f"{identifier}-{version}-{url}",
                 grant=DeviceCodeGrant(
                     identifier=identifier,
@@ -58,7 +63,7 @@ def easy(
         ),
         herre=Herre(
             grant=HerreCacheGrant(
-                cache_file=f"{identifier}-{version}_herre_cache.json",
+                cache_file=f".arkitekt/cache/{identifier}-{version}_herre_cache.json",
                 hash=f"{identifier}-{version}-{url}",
                 grant=RefreshGrant(grant=FaktsGrant()),
             ),
@@ -66,7 +71,7 @@ def easy(
     )
 
 
-def qt(version: str, identifier: str, parent) -> Arkitekt:
+def qt(identifier: str, version: str, parent) -> Arkitekt:
     """
     A simple way to create an Arkitekt app within a Qt application stilll
     utilizing a device code grant to authenticate the user on an application
@@ -75,11 +80,14 @@ def qt(version: str, identifier: str, parent) -> Arkitekt:
 
     from koil.composition.qt import QtPedanticKoil
 
+
+    create_arkitekt_folder(with_cache=True)
+
     return Arkitekt(
         koil=QtPedanticKoil(parent=parent),
         fakts=Fakts(
             grant=CacheGrant(
-                cache_file=f"{identifier}-{version}_cache.json",
+                cache_file=f".arkitekt/cache/{identifier}-{version}_cache.json",
                 grant=DeviceCodeGrant(
                     identifier=identifier,
                     version=version,
@@ -89,7 +97,7 @@ def qt(version: str, identifier: str, parent) -> Arkitekt:
         ),
         herre=Herre(
             grant=HerreCacheGrant(
-                cache_file=f"{identifier}-{version}_herre_cache.json",
+                cache_file=f".arkitekt/cache/{identifier}-{version}_herre_cache.json",
                 hash=f"{identifier}-{version}",
                 grant=FaktsGrant(),
             ),
@@ -119,6 +127,8 @@ def publicqt(identifier: str, version: str = "latest",  parent = None) -> Arkite
     from fakts.discovery.qt.selectable_beacon import SelectBeaconWidget, QtSelectableDiscovery
 
 
+    create_arkitekt_folder(with_cache=True)
+
     x = SelectBeaconWidget(parent=parent)
 
     loginWindow = LoginWidget(identifier, version, parent=parent)
@@ -127,7 +137,7 @@ def publicqt(identifier: str, version: str = "latest",  parent = None) -> Arkite
         fakts=Fakts(
             grant=CacheGrant(
                 skip_cache=True,
-                cache_file=f"{identifier}-{version}_fakts_cache.json",
+                cache_file=f".arkitekt/cache/{identifier}-{version}_fakts_cache.json",
                 grant=RetrieveGrant(
                             identifier=identifier,
                             version=version,
@@ -141,7 +151,7 @@ def publicqt(identifier: str, version: str = "latest",  parent = None) -> Arkite
         ),
         herre=Herre(
             grant=HerreCacheGrant(
-                cache_file=f"{identifier}-{version}_herre_cache.json",
+                cache_file=f".arkitekt/cache/{identifier}-{version}_herre_cache.json",
                 hash=f"{identifier}-{version}",
                 skip_cache=True,
                 grant=FaktsQtLoginScreen(
@@ -167,10 +177,13 @@ def flussi(
 
     from arkitekt.apps.fluss import ConnectedFluss
 
+
+    create_arkitekt_folder(with_cache=True)
+
     return ConnectedFluss(
         fakts=Fakts(
             grant=CacheGrant(
-                cache_file=f"{identifier}-{version}_cache.json",
+                cache_file=f".arkitekt/cache/{identifier}-{version}_cache.json",
                 hash=f"{identifier}-{version}-{url}",
                 grant=DeviceCodeGrant(
                     identifier=identifier,
@@ -181,7 +194,7 @@ def flussi(
         ),
         herre=Herre(
             grant=HerreCacheGrant(
-                cache_file=f"{identifier}-{version}_herre_cache.json",
+                cache_file=f".arkitekt/cache/{identifier}-{version}_herre_cache.json",
                 hash=f"{identifier}-{version}-{url}",
                 grant=RefreshGrant(grant=FaktsGrant()),
             ),
